@@ -1,10 +1,12 @@
 use serde::Deserialize;
 
+use crate::youtube::{parse_subscribers, Badge, SimpleText, Thumbnails};
+
 pub mod about;
 
 pub type Result<T> = super::Result<Ok<T>>;
 
-#[derive(Debug, Deserialize, Clone)]
+#[derive(Deserialize, Clone)]
 #[serde(rename_all = "camelCase")]
 pub struct Ok<T> {
     pub header: Header,
@@ -22,17 +24,17 @@ impl<T> Ok<T> {
                 Tab::Some { tab_renderer } => Some(&tab_renderer.content),
                 Tab::None {} => None,
             })
-            .expect("where")
+            .expect("channel response did not contain a opened tab")
     }
 }
 
-#[derive(Debug, Deserialize, Clone)]
+#[derive(Deserialize, Clone)]
 #[serde(rename_all = "camelCase")]
 pub struct Header {
     pub c4_tabbed_header_renderer: C4TabbedHeaderRenderer,
 }
 
-#[derive(Debug, Deserialize, Clone)]
+#[derive(Deserialize, Clone)]
 #[serde(rename_all = "camelCase")]
 pub struct C4TabbedHeaderRenderer {
     pub title: String,
@@ -42,50 +44,48 @@ pub struct C4TabbedHeaderRenderer {
     pub banner: Thumbnails,
     #[serde(default)]
     pub badges: Vec<Badge>,
-    pub subscriber_count_text: SimpleText,
+    pub subscriber_count_text: Option<SimpleText>,
 }
 
-#[derive(Debug, Deserialize, Default, Clone)]
-#[serde(rename_all = "camelCase")]
-pub struct Thumbnails {
-    pub thumbnails: Vec<crate::Thumbnail>,
+impl C4TabbedHeaderRenderer {
+    pub fn subscribers(&self) -> Option<u64> {
+        self.subscriber_count_text.as_ref().map(|x| {
+            parse_subscribers(
+                x.simple_text
+                    .split_once(' ')
+                    .expect("no space in subscriber_count_text")
+                    .0,
+            )
+            .expect("Unable to parse subscriber count")
+        })
+    }
 }
 
-#[derive(Debug, Deserialize, Clone)]
+#[derive(Deserialize, Clone)]
 #[serde(rename_all = "camelCase")]
 pub struct Metadata {
     pub channel_metadata_renderer: ChannelMetadataRenderer,
 }
 
-#[derive(Debug, Deserialize, Clone)]
+#[derive(Deserialize, Clone)]
 #[serde(rename_all = "camelCase")]
 pub struct ChannelMetadataRenderer {
     pub is_family_safe: bool,
 }
 
-#[derive(Debug, Deserialize, Clone)]
+#[derive(Deserialize, Clone)]
 #[serde(rename_all = "camelCase")]
 pub struct Contents<T> {
     pub two_column_browse_results_renderer: TwoColumnBrowseResultsRenderer<T>,
 }
 
-#[derive(Debug, Deserialize, Clone)]
+#[derive(Deserialize, Clone)]
 #[serde(rename_all = "camelCase")]
 pub struct TwoColumnBrowseResultsRenderer<T> {
     pub tabs: Vec<Tab<T>>,
 }
 
-#[derive(Debug, Deserialize, Clone)]
-#[serde(rename_all = "camelCase")]
-pub struct SimpleText {
-    pub simple_text: String,
-}
-
-#[derive(Debug, Deserialize, Clone)]
-#[serde(rename_all = "camelCase")]
-pub struct Empty {}
-
-#[derive(Debug, Deserialize, Clone)]
+#[derive(Deserialize, Clone)]
 #[serde(rename_all = "camelCase", untagged)]
 pub enum Tab<T> {
     Some {
@@ -95,20 +95,8 @@ pub enum Tab<T> {
     None {},
 }
 
-#[derive(Debug, Deserialize, Clone)]
+#[derive(Deserialize, Clone)]
 #[serde(rename_all = "camelCase")]
 pub struct TabRenderer<T> {
     pub content: T,
 }
-
-#[derive(Debug, Deserialize, Clone)]
-#[serde(rename_all = "camelCase")]
-pub struct Badge {
-    pub metadata_badge_renderer: MetadataBadgeRenderer,
-}
-
-#[derive(Debug, Deserialize, Clone)]
-#[serde(rename_all = "camelCase")]
-pub struct MetadataBadgeRenderer {
-    pub style: String,
-}
